
Automatically generates stubs for `pyxmolpp2 <https://github.com/sizmailov/pyxmolpp2>`_
using `pybind11_stubsgen <https://github.com/sizmailov/pybind11_stubsgen>`_


Install
=======


.. code-block::

    python -m pip install pyxmolpp2-stubs


Reinstall after pyxmolpp2 update
================================


.. code-block::

    python -m pip install --upgrade --force-reinstall --no-cache-dir --no-deps --user pyxmolpp2-stubs